@@ -129,6 +129,14 @@ def expand(filename):
     """
     return os.path.abspath(os.path.expandvars(os.path.expanduser(filename)))
 
+def expands(*filenames):
+    """Expand user and expand vars for the given filenames.
+    """
+    results = []
+    for filename in filenames:
+        results.append(expand(filename))
+    return results
+
 def first_exists_file(*filenames, default=None):
     """Return the first exists file's abspath. If none file exists, return None.
     """
@@ -137,3 +145,31 @@ def first_exists_file(*filenames, default=None):
         if os.path.exists(filename):
             return filename
     return default
+
+def get_application_config_filepath(appname, name="config", suffix="yml"):
+    """Get application config filepath by search these places:
+        ./{appname}-{name}.{suffix}
+        ./conf/{appname}-{name}.{suffix}
+        ./etc/{appname}-{name}.{suffix}
+        ~/.{appname}/{name}.{suffix}
+        ~/{appname}/{name}.{suffix}
+    """
+    return first_exists_file(
+        "./{0}-{1}.{2}".format(appname, name, suffix),
+        "./conf/{0}-{1}.{2}".format(appname, name, suffix),
+        "./etc/{0}-{1}.{2}".format(appname, name, suffix),
+        "~/.{0}/{1}.{2}".format(appname, name, suffix),
+        "~/{0}/{1}.{2}".format(appname, name, suffix),
+    )
+
+def info(filename):
+    ext = os.path.splitext(filename)[1]
+    stat = os.stat(filename)
+    return {
+        "ext": ext,
+        "abspath": os.path.abspath(filename),
+        "size": stat.st_size,
+        "atime": datetime.datetime.fromtimestamp(stat.st_atime),
+        "ctime": datetime.datetime.fromtimestamp(stat.st_ctime),
+        "mode": stat.st_mode,
+    }
