@@ -1,8 +1,15 @@
 # -*- coding: utf-8 -*-
+import time
+import functools
+import logging
 from inspect import signature
-from . import typingutils
+
 import bizerror
 
+from . import typingutils
+
+
+logger = logging.getLogger(__name__)
 
 def get_default_values(func):
     data = {}
@@ -76,3 +83,27 @@ class BunchCallable(object):
         else:
             return None
 
+
+def try_again_on_error(sleep: int=5, limit: int=0, callback=None, callback_args=None, callback_kwargs=None):
+    def outter_wrapper(func):
+        def wrapper(*args, **kwargs):
+            counter = 0
+            while True:
+                counter += 1
+                try:
+                    return func(*args, **kwargs)
+                except InterruptedError:
+                    logger.info("exit on got InterruptedError...")
+                    break
+                except Exception as error:
+                    logger.exception("got unknown exception: {0}".format(str(error)))
+                    if callback:
+                        logger.info("call callback function {0} with params {1} {2}".format(str(callback), str(callback_args), str(callback_kwargs)))
+                        local_callback_args = callback_args or []
+                        local_callback_kwargs = callback_kwargs or {}
+                        callback(*local_callback_args, **local_callback_kwargs)
+                    time.sleep(sleep)
+                if limit and counter >= limit:
+                    break
+        return functools.wraps(func)(wrapper)
+    return outter_wrapper
