@@ -599,3 +599,17 @@ def remove_suffix(thestring, suffix):
             return thestring
     else:
         return thestring
+
+def encodable(value, encoding="utf-8"):
+    try:
+        value.encode(encoding)
+        return True
+    except UnicodeEncodeError:
+        return False
+
+def decodable(value, encoding="utf-8"):
+    try:
+        value.decode(encoding)
+        return True
+    except UnicodeDecodeError:
+        return False
